diff --git a/src/bin/pgbench/pgbench.c b/src/bin/pgbench/pgbench.c
index ee1134aea2..44bebed717 100644
--- a/src/bin/pgbench/pgbench.c
+++ b/src/bin/pgbench/pgbench.c
@@ -3295,7 +3295,7 @@ executeMetaCommand(CState *st, instr_time *now)
 	argc = command->argc;
 	argv = command->argv;
 
-	if (unlikely(__pg_log_level <= PG_LOG_DEBUG))
+	if (pg_log_debug_level)
 	{
 		fprintf(stderr, "client %d executing \\%s", st->id, argv[0]);
 		for (int i = 1; i < argc; i++)
diff --git a/src/include/common/logging.h b/src/include/common/logging.h
index 028149c7a1..c4af92a4d9 100644
--- a/src/include/common/logging.h
+++ b/src/include/common/logging.h
@@ -72,24 +72,29 @@ void		pg_logging_set_locus_callback(void (*cb) (const char **filename, uint64 *l
 void		pg_log_generic(enum pg_log_level level, const char *pg_restrict fmt,...) pg_attribute_printf(2, 3);
 void		pg_log_generic_v(enum pg_log_level level, const char *pg_restrict fmt, va_list ap) pg_attribute_printf(2, 0);
 
+#define pg_log_fatal_level (likely(__pg_log_level <= PG_LOG_FATAL))
 #define pg_log_fatal(...) do { \
-		if (likely(__pg_log_level <= PG_LOG_FATAL)) pg_log_generic(PG_LOG_FATAL, __VA_ARGS__); \
+		if (pg_log_fatal_level) pg_log_generic(PG_LOG_FATAL, __VA_ARGS__); \
 	} while(0)
 
+#define pg_log_error_level (likely(__pg_log_level <= PG_LOG_ERROR))
 #define pg_log_error(...) do { \
-		if (likely(__pg_log_level <= PG_LOG_ERROR)) pg_log_generic(PG_LOG_ERROR, __VA_ARGS__); \
+		if (pg_log_error_level) pg_log_generic(PG_LOG_ERROR, __VA_ARGS__); \
 	} while(0)
 
+#define pg_log_warning_level (likely(__pg_log_level <= PG_LOG_WARNING))
 #define pg_log_warning(...) do { \
-		if (likely(__pg_log_level <= PG_LOG_WARNING)) pg_log_generic(PG_LOG_WARNING, __VA_ARGS__); \
+		if (pg_log_warning_level) pg_log_generic(PG_LOG_WARNING, __VA_ARGS__); \
 	} while(0)
 
+#define pg_log_info_level (likely(__pg_log_level <= PG_LOG_INFO))
 #define pg_log_info(...) do { \
-		if (likely(__pg_log_level <= PG_LOG_INFO)) pg_log_generic(PG_LOG_INFO, __VA_ARGS__); \
+		if (pg_log_info_level) pg_log_generic(PG_LOG_INFO, __VA_ARGS__); \
 	} while(0)
 
+#define pg_log_debug_level (unlikely(__pg_log_level <= PG_LOG_DEBUG))
 #define pg_log_debug(...) do { \
-		if (unlikely(__pg_log_level <= PG_LOG_DEBUG)) pg_log_generic(PG_LOG_DEBUG, __VA_ARGS__); \
+		if (pg_log_debug_level) pg_log_generic(PG_LOG_DEBUG, __VA_ARGS__); \
 	} while(0)
 
 #endif							/* COMMON_LOGGING_H */
